@@ -36,6 +36,7 @@ def fbrowser_update_fields(window,contcar_str,mws_dict,str_folderbrowser):
     window['--I_p_evac'].update('8')
     window['--I_p_svac'].update('2')
     window['--I_Ti'].update('0.1')
+    window['--I_Pi'].update('0')
     window['--I_Tm'].update('1000')
     window['--I_Tf'].update(window['--I_Tm'].get())
     window['--I_ntemps'].update(20)
@@ -77,6 +78,7 @@ def update_diabled(window,opened_dict,eos_available,bool_dict_params_EOS):
     window['--Chk_intanh'].update(disabled=True if window['--I_compound'].get()=='' else False)
     window['--Chk_anhxc'].update(disabled=True if window['--I_compound'].get()=='' else False)
     window['--I_Ti'].update(disabled=True if window['--I_compound'].get()=='' else False)
+    window['--I_Pi'].update(disabled=True if window['--I_compound'].get()=='' else False)
     window['--I_Tf'].update(disabled=True if window['--I_compound'].get()=='' else False)
     window['--I_Tm'].update(disabled=True if window['--I_compound'].get()=='' else False)
     window['--I_ntemps'].update(disabled=True if window['--I_compound'].get()=='' else False)
